connect_with_retry

Function connect_with_retry 

pub fn connect_with_retry(path: &Path) -> Option<UnixDatagram>
Wait for the remote process to bind path, intentionally naive. Returns None if the socket is still unavailable after 30 seconds.